﻿/*
 * Programa para el ESP-01 que contiene un ESP8266 y se utiliza como Servidor Principal
 * en donde se listan todos los demás ESP-01 con IPs de 192.168.0.195 . . . 196, 197,
 * 198, 199 y 200, para poder accederlos vía un navegador en SmartPhone, PC, Laptop,
 * Tablet, SmartTV, etc.
 * Es una página Web, en donde aparecen  los dispositivos WiFi remotos que controlan 
 * los focos de ciertas zonas de la residencia, por ejempo, "Comedor", Patio Trasero, 
 * "Patio Delantero", etc.
 * 
 * Este Web tiene la IP 192.168.0.201 para mi caso.
 * 
 * Alfredo Segura, Queretaro Mexico marzo de 2022
 * 
 * Nota: Si se requiere compartir este archivo, deberán borrarse los datos personales
 * de la IP, la SSID y el PASSWORD.
 * 
 */

#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <ESP8266mDNS.h>
#include <DNSServer.h>

#ifndef STASSID
#define STASSID "Aqui el nombre de tu red WiFi"
#define STAPSK  "Aqui el password de tu red"
#endif

const char *ssid = STASSID;
const char *password = STAPSK;

IPAddress ip(192,168,0,201);    // Web Server Principal
IPAddress gateway(192,168,0,1);   
IPAddress subnet(255,255,255,0); 
IPAddress dnServer(192,168,0,1);

ESP8266WebServer server(80);


#define MAXmibuffer2  4000
char mibuffer2[MAXmibuffer2 + 1];

static const char  Iniciohtml[] = "<!DOCTYPE HTML>\r\n \
<html><TITLE>SERVER WEB IoT-Home - ESP8266 </TITLE>";

static const char  cuerpo1[] = "<body>Elegir el Foco a controlar: \
<p></p><p></p> \
<h4>Foco en:</h4> \
<a href='http://192.168.0.200' target='_blank'>Comedor</a> \
<p></p><p></p> \
<a href='http://192.168.0.199' target='_blank'>Cocina</a> \
<p></p><p></p> \
<a href='http://192.168.0.198' target='_blank'>Pasillo Puerta</a> \
<p></p><p></p> \
<a href='http://192.168.0.197' target='_blank'>Taller</a> \
<p></p><p></p> \
<a href='http://192.168.0.196' target='_blank'>Patio Frontal</a> \
<p></p><p></p> \
<a href='http://192.168.0.195' target='_blank'>Patio Trasero</a> \
<p></p><p></p> \
";

static const char final[] = "<p></p><p></p> \
<a href='http://192.168.0.201'>Refrescar</a> \
</body></html> \
";

void handleRoot()
{
  int z;
  strcpy(mibuffer2, Iniciohtml);
  
  strcat(mibuffer2, cuerpo1); 
  
  strcat(mibuffer2, final);
  z = strlen(mibuffer2);
  server.send(z, "text/html", mibuffer2 );
}

void handleNotFound()
{
  String message = "File Not Found\n\n";
  server.send(404, "text/plain", message);
}

void setup(void) {
 
  WiFi.mode(WIFI_STA);
  WiFi.config(ip, gateway, subnet);
  WiFi.begin(ssid, password);

  // Wait for connection
  while (WiFi.status() != WL_CONNECTED) 
  {
    delay(500);
  }

  if (MDNS.begin("esp8266")) {
    //Serial.println("MDNS responder started");
  }

  MDNS.begin("esp8266");

  server.on("/", handleRoot);

  server.on("/ok", []() {    server.send(200, "text/plain", "TRABAJA BIEN");  });

  server.onNotFound(handleNotFound);

  server.begin();
}

void loop(void) 
{
  server.handleClient();
  MDNS.update();
}
